@@ -2,6 +2,9 @@ import numpy as np
 import math
 
 from Deep_Learning_Framework import *
+from Deep_Learning_Framework.activations import softmax
+from Deep_Learning_Framework.layer import ActivationLayer
+from Deep_Learning_Framework.loss import Loss
 
 
 def change_to_vector(y):
